==> dde-network-core_1.0.57.orig.tar.xz: dde-network-core-1.0.57/dock-network-plugin/translations/dock-network-plugin_uk.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="uk" version="2.1">
<context>
    <name>NetworkPlugin</name>
    <message>
        <source>Network</source>
        <translation>Мережа</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>Точка доступу</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Протокол</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Тип захисту</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Група</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Канал</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Інтерфейс</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Маска мережі</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Шлюз</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>Основний DNS</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Префікс</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Швидкість</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Пристрій вимкнено</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>З&apos;єднано, але немає доступу до інтернету</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Не з&apos;єднано</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Кабель мережі від&apos;єднано</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>З&apos;єднання</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>Розпізнавання</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>Отримуємо IP-адресу</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>З&apos;єднано</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Роз&apos;єднано</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Конфлікт IP</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Помилка</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>Отримання адреси</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Дротова мережа</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Дротова мережа %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Бездротова мережа</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Бездротова мережа %1</translation>
    </message>
</context>
<context>
    <name>dde::networkplugin::NetworkPluginHelper</name>
    <message>
        <source>Device disabled</source>
        <translation>Пристрій вимкнено</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Кабель мережі від&apos;єднано</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Не з&apos;єднано</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>З&apos;єднання</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>З&apos;єднано, але немає доступу до інтернету</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>Не вдалося встановити з&apos;єднання</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Конфлікт IP</translation>
    </message>
    <message>
        <source>Disable wired connection</source>
        <translation>Вимкнути дротове з&apos;єднання</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Увімкнути дротове з&apos;єднання</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Вимкнути бездротове з&apos;єднання</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Увімкнути бездротове з&apos;єднання</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Вимкнути мережу</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Увімкнути мережу</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Параметри мережі</translation>
    </message>
</context>
</TS>

==> dde-network-core_1.1.4.orig.tar.xz: dde-network-core-1.1.4/dock-network-plugin/translations/dock-network-plugin_uk.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="uk">
<context>
    <name>DeviceControllItem</name>
    <message>
        <source>Wireless Network</source>
        <translation>Бездротова мережа</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Провідна мережа</translation>
    </message>
</context>
<context>
    <name>NetworkPlugin</name>
    <message>
        <source>Network</source>
        <translation>Мережа</translation>
    </message>
</context>
<context>
    <name>WirelessItem</name>
    <message>
        <source>Connect to hidden network</source>
        <translation>Встановлення з&apos;єднання із прихованою мережею</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Пароль</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Скасувати</translation>
    </message>
    <message>
        <source>Connect</source>
        <comment>button</comment>
        <translation>З&apos;єднатися</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation>Назва (SSID)</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>Точка доступу</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Протокол</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Тип захисту</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Канал</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Група</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Інтерфейс</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Маска мережі</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Шлюз</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>Основний DNS</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Префікс</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Швидкість</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Пристрій вимкнено</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>З&apos;єднано, але немає доступу до інтернету</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Не з&apos;єднано</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Кабель мережі від&apos;єднано</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>З&apos;єднання</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>Розпізнавання</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>Отримуємо IP-адресу</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>З&apos;єднано</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Роз&apos;єднано</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Конфлікт IP</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Помилка</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>Отримання адреси</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Дротова мережа</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Дротова мережа %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Бездротова мережа</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Бездротова мережа %1</translation>
    </message>
</context>
<context>
    <name>dde::networkplugin::NetworkPluginHelper</name>
    <message>
        <source>Device disabled</source>
        <translation>Пристрій вимкнено</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Кабель мережі від&apos;єднано</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Не з&apos;єднано</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>З&apos;єднання</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>З&apos;єднано, але немає доступу до інтернету</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>Не вдалося встановити з&apos;єднання</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Конфлікт IP</translation>
    </message>
    <message>
        <source>Disable wired connection</source>
        <translation>Вимкнути дротове з&apos;єднання</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Увімкнути дротове з&apos;єднання</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Вимкнути бездротове з&apos;єднання</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Увімкнути бездротове з&apos;єднання</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Вимкнути мережу</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Увімкнути мережу</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Параметри мережі</translation>
    </message>
</context>
</TS>
